==> libwpd_0.8.4.orig.tar.gz: libwpd-0.8.4/src/lib/WP6FillStylePacket.h <==
/* libwpd
 * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
 * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP6FILLSTYLEPACKET_H
#define WP6FILLSTYLEPACKET_H
#include "WP6PrefixDataPacket.h"
#include "WP6FileStructure.h"
#include "libwpd_internal.h"

struct _RGBSColor;
typedef struct _RGBSColor RGBSColor; 

class WP6FillStylePacket : public WP6PrefixDataPacket
{
public:
	WP6FillStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
	virtual ~WP6FillStylePacket();
	virtual void _readContents(WPXInputStream *input);
	virtual void parse(WP6Listener *listener) const {}
	const RGBSColor * getFgColor() const { return &m_fgColor; }
	const RGBSColor * getBgColor() const { return &m_bgColor; }
private:              
	RGBSColor m_fgColor;
	RGBSColor m_bgColor;
};
#endif /* WP6FILLSTYLEPACKET_H */

==> libwpd_0.8.7.orig.tar.gz: libwpd-0.8.7/src/lib/WP6FillStylePacket.h <==
/* libwpd
 * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP6FILLSTYLEPACKET_H
#define WP6FILLSTYLEPACKET_H
#include "WP6PrefixDataPacket.h"
#include "WP6FileStructure.h"
#include "libwpd_internal.h"

struct _RGBSColor;
typedef struct _RGBSColor RGBSColor; 

class WP6FillStylePacket : public WP6PrefixDataPacket
{
public:
	WP6FillStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
	~WP6FillStylePacket();
	void _readContents(WPXInputStream *input);
	void parse(WP6Listener *listener) const {}
	const RGBSColor * getFgColor() const { return &m_fgColor; }
	const RGBSColor * getBgColor() const { return &m_bgColor; }
private:              
	RGBSColor m_fgColor;
	RGBSColor m_bgColor;
};
#endif /* WP6FILLSTYLEPACKET_H */
